==> bluez-qt-5.99.0-1-aarch64.pkg.tar.xz: usr/include/KF5/BluezQt/bluezqt/bluezqt_export.h <==

#ifndef BLUEZQT_EXPORT_H
#define BLUEZQT_EXPORT_H

#ifdef BLUEZQT_STATIC_DEFINE
#  define BLUEZQT_EXPORT
#  define BLUEZQT_NO_EXPORT
#else
#  ifndef BLUEZQT_EXPORT
#    ifdef KF5BluezQt_EXPORTS
        /* We are building this library */
#      define BLUEZQT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define BLUEZQT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef BLUEZQT_NO_EXPORT
#    define BLUEZQT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef BLUEZQT_DECL_DEPRECATED
#  define BLUEZQT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef BLUEZQT_DECL_DEPRECATED_EXPORT
#  define BLUEZQT_DECL_DEPRECATED_EXPORT BLUEZQT_EXPORT BLUEZQT_DECL_DEPRECATED
#endif

#ifndef BLUEZQT_DECL_DEPRECATED_NO_EXPORT
#  define BLUEZQT_DECL_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT BLUEZQT_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef BLUEZQT_NO_DEPRECATED
#    define BLUEZQT_NO_DEPRECATED
#  endif
#endif

#define BLUEZQT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(BLUEZQT_NO_DEPRECATED) && !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define BLUEZQT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(BLUEZQT_NO_DEPRECATED_WARNINGS) && !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define BLUEZQT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(BLUEZQT_NO_DEPRECATED)
#  undef BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#elif defined(BLUEZQT_NO_DEPRECATED_WARNINGS)
#  define BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#else
#  define BLUEZQT_DEPRECATED BLUEZQT_DECL_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_DECL_DEPRECATED_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define BLUEZQT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef BLUEZQT_NO_DEPRECATED
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56300
#endif
#ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef BLUEZQT_DEPRECATED_WARNINGS_SINCE
#  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x56300
#  endif
#endif

#ifndef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef BLUEZQT_DEPRECATED
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if BLUEZQT_DEPRECATED_WARNINGS_SINCE >= 0x53900
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text) BLUEZQT_DECL_DEPRECATED_TEXT(text)
#else
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text)
#endif
#define BLUEZQT_DEPRECATED_VERSION_5(minor, text)      BLUEZQT_DEPRECATED_VERSION_5_##minor(text)
#define BLUEZQT_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* BLUEZQT_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_BLUEZQT_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_BLUEZQT_EXPORT_H


#define BLUEZQT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(BLUEZQT_NO_DEPRECATED) && !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define BLUEZQT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(BLUEZQT_NO_DEPRECATED_WARNINGS) && !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define BLUEZQT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(BLUEZQT_NO_DEPRECATED)
#  undef BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#elif defined(BLUEZQT_NO_DEPRECATED_WARNINGS)
#  define BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#else
#  define BLUEZQT_DEPRECATED BLUEZQT_DECL_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_DECL_DEPRECATED_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define BLUEZQT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef BLUEZQT_NO_DEPRECATED
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56300
#endif
#ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef BLUEZQT_DEPRECATED_WARNINGS_SINCE
#  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x56300
#  endif
#endif

#ifndef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef BLUEZQT_DEPRECATED
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if BLUEZQT_DEPRECATED_WARNINGS_SINCE >= 0x53900
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text) BLUEZQT_DECL_DEPRECATED_TEXT(text)
#else
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text)
#endif
#define BLUEZQT_DEPRECATED_VERSION_5(minor, text)      BLUEZQT_DEPRECATED_VERSION_5_##minor(text)
#define BLUEZQT_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_BLUEZQT_EXPORT_H */

==> bluez-qt-5.107.0-1-aarch64.pkg.tar.xz: usr/include/KF5/BluezQt/bluezqt/bluezqt_export.h <==

#ifndef BLUEZQT_EXPORT_H
#define BLUEZQT_EXPORT_H

#ifdef BLUEZQT_STATIC_DEFINE
#  define BLUEZQT_EXPORT
#  define BLUEZQT_NO_EXPORT
#else
#  ifndef BLUEZQT_EXPORT
#    ifdef KF5BluezQt_EXPORTS
        /* We are building this library */
#      define BLUEZQT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define BLUEZQT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef BLUEZQT_NO_EXPORT
#    define BLUEZQT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef BLUEZQT_DECL_DEPRECATED
#  define BLUEZQT_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef BLUEZQT_DECL_DEPRECATED_EXPORT
#  define BLUEZQT_DECL_DEPRECATED_EXPORT BLUEZQT_EXPORT BLUEZQT_DECL_DEPRECATED
#endif

#ifndef BLUEZQT_DECL_DEPRECATED_NO_EXPORT
#  define BLUEZQT_DECL_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT BLUEZQT_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef BLUEZQT_NO_DEPRECATED
#    define BLUEZQT_NO_DEPRECATED
#  endif
#endif

#define BLUEZQT_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(BLUEZQT_NO_DEPRECATED) && !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define BLUEZQT_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(BLUEZQT_NO_DEPRECATED_WARNINGS) && !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define BLUEZQT_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(BLUEZQT_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(BLUEZQT_NO_DEPRECATED)
#  undef BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#elif defined(BLUEZQT_NO_DEPRECATED_WARNINGS)
#  define BLUEZQT_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_NO_EXPORT
#else
#  define BLUEZQT_DEPRECATED BLUEZQT_DECL_DEPRECATED
#  define BLUEZQT_DEPRECATED_EXPORT BLUEZQT_DECL_DEPRECATED_EXPORT
#  define BLUEZQT_DEPRECATED_NO_EXPORT BLUEZQT_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define BLUEZQT_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define BLUEZQT_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef BLUEZQT_NO_DEPRECATED
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
#endif
#ifdef BLUEZQT_NO_DEPRECATED_WARNINGS
#  define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef BLUEZQT_DEPRECATED_WARNINGS_SINCE
#  ifdef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define BLUEZQT_DEPRECATED_WARNINGS_SINCE 0x56b00
#  endif
#endif

#ifndef BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef BLUEZQT_DEPRECATED
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > BLUEZQT_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define BLUEZQT_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if BLUEZQT_DEPRECATED_WARNINGS_SINCE >= 0x53900
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text) BLUEZQT_DECL_DEPRECATED_TEXT(text)
#else
#  define BLUEZQT_DEPRECATED_VERSION_5_57(text)
#endif
#define BLUEZQT_DEPRECATED_VERSION_5(minor, text)      BLUEZQT_DEPRECATED_VERSION_5_##minor(text)
#define BLUEZQT_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) BLUEZQT_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) BLUEZQT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define BLUEZQT_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* BLUEZQT_EXPORT_H */
